@@ -87,7 +87,9 @@ namespace Banshee
 		
 		public void SafeRun()
 		{
-			try {
+			Run();
+			
+			/*try {
 				Run();
 			} catch(Exception e) {
 				DebugLog.Add(String.Format(Catalog.GetString(
@@ -96,7 +98,7 @@ namespace Banshee
 					GetType().ToString(),
 					e.GetType().ToString(), 
 					e.Message));
-			}
+			}*/
 			
 			Finish(this);
 		}
@@ -285,10 +287,28 @@ namespace Banshee
 			if(cancelRequested)
 				return;
 				
+		    if(Path.GetFileName(file).StartsWith(".banshee-ipod-"))
+		       return;
+				
 			DateTime startStamp = DateTime.Now;
 			
 			try {
 				TrackInfo ti = new LibraryTrackInfo(file);
+				
+				bool copy = false;
+				try {
+					copy = (bool)Core.GconfClient.Get(GConfKeys.CopyOnImport);
+				} catch(Exception) {}
+				
+				if(copy) {
+					try {
+						string destfile = FileNamePattern.BuildFull(ti, 
+							Path.GetExtension(file).Substring(1));
+						File.Copy(file, destfile, true);
+						ti.Uri = destfile;
+					} catch(Exception) { }
+				}
+			
 				RaiseTrackInfo(ti);
 				UpdateAverageDuration(startStamp);
 			} catch(Exception e) {
@@ -439,8 +459,10 @@ namespace Banshee
 			totalCount = Core.Library.Tracks.Count;
 			currentCount = 0;
 			
-			foreach(TrackInfo track in Core.Library.Tracks.Values)
-				RaiseTrackInfo(track);
+			lock(Core.Library.Tracks.SyncRoot) {
+				foreach(TrackInfo track in Core.Library.Tracks.Values)
+					RaiseTrackInfo(track);
+			}
 		}
 		
 		private void RaiseTrackInfo(TrackInfo ti)
